Appearance class

author: zhengzaihong email:1096877329@qq.com date: 2025-11-19 time: 14:48 describe: 题目的外观类型

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

beginGroupChildAll → const String
beginGroupChildOneByOne → const String
dateTime → const String
draw → const String
random → const String
readOnly → const String
scriptui → const String
signature → const String
timer → const String
voice → const String
write → const String