ViewController class

author: zhengzaihong email:1096877329@qq.com date: 2025-11-20 time: 16:53 describe:

Constructors

ViewController()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureNotifier(String questionId) ValueNotifier
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifierOf(String questionId) ValueNotifier?
removeQuestion(String questionId) → void
toString() String
A string representation of this object.
inherited
updateAnswer(String questionId, dynamic value) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited