PicturePosition enum

author: zhengzaihong email:1096877329@qq.com date: 2025-11-20 time: 15:10 describe: 简化FormFactory创建view逻辑

Inheritance
Available extensions

Values

ON_LEFT_OPTION → const PicturePosition
ON_RIGHT_OPTION → const PicturePosition
ON_TOP_OPTION → const PicturePosition
ON_BOTTOM_OPTION → const PicturePosition

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PicturePosition>
A constant List of the values in this enum, in order of their declaration.