ExpressionChannel class
author: zhengzaihong email:1096877329@qq.com date: 2025-11-11 time: 16:57 describe: flutter调用Android语言表达式
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
evalNumber(
{required String expression, dynamic context, dynamic currentValue}) → Future< num?> -
evalString(
{required String expression, dynamic context, dynamic currentValue}) → Future< String?> -
evaluate(
{required String expression, dynamic context, dynamic currentValue}) → Future -
isTrue(
{required String expression, dynamic context, dynamic currentValue}) → Future< bool>