FormTextStyles class
表单文本样式类 支持主题切换和横竖屏响应式样式
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contentStyle(
{BuildContext? context, TextSizeEnum? size, Color? color}) → TextStyle - 正文样式
-
descriptionStyle(
{BuildContext? context, TextSizeEnum? size, Color? color}) → TextStyle - 描述文本样式
-
getColorScheme(
BuildContext? context) → FormColorScheme? - 获取当前有效的颜色方案
-
getStyleConfig(
BuildContext? context) → OrientationStyleConfig? - 获取当前有效的样式配置
-
scoreStyle(
{BuildContext? context, TextSizeEnum? size, Color? color}) → TextStyle? -
titleStyle(
{BuildContext? context, TextSizeEnum? size, Color? color, FontWeight? fontWeight}) → TextStyle - 标题样式(大标题/导航标题)