LogLevel enum

日志级别枚举

Inheritance
Available extensions

Values

debug → const LogLevel

调试级别 - 输出所有日志

info → const LogLevel

信息级别 - 输出信息、警告、错误日志

warn → const LogLevel

警告级别 - 输出警告、错误日志

error → const LogLevel

错误级别 - 仅输出错误日志

none → const LogLevel

关闭日志

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.