FingerGuidePosition enum

author: ZhengZaiHong email:1096877329@qq.com date: 2026-04-13 16:48 describe: 用于引导点击按钮、输入框等交互元素 手指引导位置

Inheritance
Available extensions

Values

left → const FingerGuidePosition

左侧(按钮内容左边)

右侧(按钮内容右边)

bottom → const FingerGuidePosition

底部(输入框下方)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FingerGuidePosition>
A constant List of the values in this enum, in order of their declaration.