FingerGuideWidget class

手指动画引导组件

Inheritance

Constructors

FingerGuideWidget({Key? key, bool show = true, FingerGuidePosition position = FingerGuidePosition.left, required Widget child, double fingerSize = 32, Duration animationDuration = const Duration(milliseconds: 800), double spacing = 8, double angle = 0})
const

Properties

angle double
角度
final
animationDuration Duration
动画持续时间
final
child Widget
子组件(被引导的组件)
final
fingerSize double
手指图标大小
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
position FingerGuidePosition
手指引导位置
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
show bool
是否显示手指引导
final
spacing double
手指与子组件的间距
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FingerGuideWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited