RandomUtils class
author: zhengzaihong email:1096877329@qq.com date: 2025-11-21 time: 16:33 describe: 随机数工具类
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateRandom(
{required int length, bool numericOnly = true, bool includeLetters = false}) → String -
randomAlphabetic(
int length) → String -
randomAlphanumeric(
int length) → String -
randomNumeric(
int length) → String