FormThemeConfig class
表单主题配置
Constructors
- FormThemeConfig({FormThemeMode themeMode = FormThemeMode.system, required OrientationStyleConfig lightPortrait, required OrientationStyleConfig lightLandscape, required OrientationStyleConfig darkPortrait, required OrientationStyleConfig darkLandscape, required FormColorScheme lightColors, required FormColorScheme darkColors})
-
const
- FormThemeConfig.defaultConfig()
-
创建默认配置
factory
Properties
- darkColors → FormColorScheme
-
暗色主题颜色
final
- darkLandscape → OrientationStyleConfig
-
暗色主题的横屏样式
final
- darkPortrait → OrientationStyleConfig
-
暗色主题的竖屏样式
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lightColors → FormColorScheme
-
亮色主题颜色
final
- lightLandscape → OrientationStyleConfig
-
亮色主题的横屏样式
final
- lightPortrait → OrientationStyleConfig
-
亮色主题的竖屏样式
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- themeMode → FormThemeMode
-
主题模式
final
Methods
-
copyWith(
{FormThemeMode? themeMode, OrientationStyleConfig? lightPortrait, OrientationStyleConfig? lightLandscape, OrientationStyleConfig? darkPortrait, OrientationStyleConfig? darkLandscape, FormColorScheme? lightColors, FormColorScheme? darkColors}) → FormThemeConfig - 复制并修改
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited