OrientationStyleConfig class
横竖屏样式配置
Constructors
- OrientationStyleConfig({required TextStyleConfig titleStyle, required TextStyleConfig descriptionStyle, required TextStyleConfig contentStyle, required TextStyleConfig scoreStyle})
-
const
- OrientationStyleConfig.defaultLandscape()
-
创建默认横屏配置
factory
- OrientationStyleConfig.defaultPortrait()
-
创建默认配置
factory
Properties
- contentStyle → TextStyleConfig
-
正文样式配置
final
- descriptionStyle → TextStyleConfig
-
描述样式配置
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scoreStyle → TextStyleConfig
-
分数样式配置
final
- titleStyle → TextStyleConfig
-
标题样式配置
final
Methods
-
copyWith(
{TextStyleConfig? titleStyle, TextStyleConfig? descriptionStyle, TextStyleConfig? contentStyle, TextStyleConfig? scoreStyle}) → OrientationStyleConfig - 复制并修改
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited