FormLogger class
author: zhengzaihong email:1096877329@qq.com date: 2025-11-20 time: 15:10 describe: 表单库日志工具类
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clear(
String message, {String? tag}) → void - 清除操作相关日志
-
collect(
String message, {String? tag}) → void - 答案收集相关日志
-
debug(
String message, {String? tag}) → void - 调试日志 - 用于详细的调试信息
-
error(
String message, {String? tag, Object? error, StackTrace? stackTrace}) → void - 错误日志 - 用于错误信息
-
expression(
String message, {String? tag}) → void - 表达式计算相关日志
-
info(
String message, {String? tag}) → void - 信息日志 - 用于一般信息
-
inject(
String message, {String? tag}) → void - 注入上下文相关日志
-
save(
String message, {String? tag}) → void - 保存操作相关日志
-
setEnabled(
bool enabled) → void - 设置是否启用日志
-
setLevel(
LogLevel level) → void - 设置日志级别
-
success(
String message, {String? tag}) → void - 成功日志 - 用于操作成功的信息
-
update(
String message, {String? tag}) → void - 更新操作相关日志
-
warn(
String message, {String? tag}) → void - 警告日志 - 用于警告信息