ScreenUtils class
author: zhengzaihong email:1096877329@qq.com date: 2024/9/6 time: 11:06 describe: 应用内的通用方法
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
horizontalScreen(
) → void - 横屏
-
verticalScreen(
) → void